@@ -198,7 +198,7 @@ class Mailer(object):
                 self["Content-Id"] = "<%s>" % to_native(content_id, encoding)
             Encoders.encode_base64(self)
 
-    def __init__(self, server=None, sender=None, login=None, tls=True):
+    def __init__(self, server=None, sender=None, login=None, tls=True, ssl=False):
 
         settings = self.settings = Settings()
         settings.logger = logging
@@ -208,7 +208,7 @@ class Mailer(object):
         settings.tls = tls
         settings.timeout = 5  # seconds
         settings.hostname = None
-        settings.ssl = False
+        settings.ssl = ssl
         settings.cipher_type = None
         settings.gpg_home = None
         settings.sign = True
